==> haskell-unicode-show-0.1.1.1-66-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-show
version:              0.1.1.1
visibility:           public
id:                   unicode-show-0.1.1.1-C4u04fePSqvFJg2rcMuRhX
key:                  unicode-show-0.1.1.1-C4u04fePSqvFJg2rcMuRhX
license:              BSD-3-Clause
copyright:            2016 Takayuki Muranushi
maintainer:           igrep@n.email.ne.jp
author:               Takayuki Muranushi
homepage:             http://github.com/haskell-jp/unicode-show#readme
synopsis:             print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.

    See <http://github.com/haskell-jp/unicode-show#readme README> for usage.

    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.

category:             Text
abi:                  5f5e7a7be40daa4f886a9a43f68d2930
exposed:              True
exposed-modules:      Text.Show.Unicode
import-dirs:          /usr/lib/ghc-9.2.8/site-local/unicode-show-0.1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/unicode-show-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-show
hs-libraries:         HSunicode-show-0.1.1.1-C4u04fePSqvFJg2rcMuRhX
depends:
    base-4.16.4.0 safe-0.3.21-iv9yHEgDynJNZkwcC9KXL
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock

haddock-html:         /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-show-0.1.1.1-68-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-show
version:              0.1.1.1
visibility:           public
id:                   unicode-show-0.1.1.1-FQxywzJ5NNmAcdrI8o9qid
key:                  unicode-show-0.1.1.1-FQxywzJ5NNmAcdrI8o9qid
license:              BSD-3-Clause
copyright:            2016 Takayuki Muranushi
maintainer:           igrep@n.email.ne.jp
author:               Takayuki Muranushi
homepage:             http://github.com/haskell-jp/unicode-show#readme
synopsis:             print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.

    See <http://github.com/haskell-jp/unicode-show#readme README> for usage.

    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.

category:             Text
abi:                  ad1ea404f2c7a254e62156b28b193e87
exposed:              True
exposed-modules:      Text.Show.Unicode
import-dirs:          /usr/lib/ghc-9.2.8/site-local/unicode-show-0.1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/unicode-show-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-show
hs-libraries:         HSunicode-show-0.1.1.1-FQxywzJ5NNmAcdrI8o9qid
depends:
    base-4.16.4.0 safe-0.3.21-98IVtOx0Wmj8cqPHUtTkEF
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock

haddock-html:         /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
